pub enum SettingsStoreError {
Io(Error),
Parse(Error),
Flush(FlushError),
}Expand description
Errors surfaced by SettingsStore::open.
Variants
Io(Error)
The settings file could not be read or written (missing directory, permission denied, etc.).
Parse(Error)
The settings file exists but its contents are not valid TOML.
Flush(FlushError)
An attempt to flush the in-memory state to disk failed.